[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - PyLucene.Object: j_object objects
    - PyLucene.Field: j_field objects
    - PyLucene.Document: j_document objects
  - threading._Verbose
    - threading.Thread
      - PyLucene.PythonThread: A threading.Thread extension that delegates starting of the actual OS thread to libgcj.
        - turbolucene._SearcherFactory: Produces running _Searcher threads.
        - turbolucene._Searcher: Responsible for searching an index and returning results.
        - turbolucene._Indexer: Responsible for updating and maintaining the search engine index.